@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8
-from __future__ import unicode_literals, absolute_import
+from __future__ import absolute_import, unicode_literals
 
 import os
 import sys
